@@ -27,6 +27,13 @@
 
 #ifdef system_arm
 
+static char *implementer[] =
+{
+    "0x41", "ARM",
+    "0x50", "APM",
+    NULL, NULL
+};
+
 void GetHardwareInfo(int fd, struct hw_stat *hw)
 {
 	int processors = 0; 
@@ -36,6 +43,10 @@ void GetHardwareInfo(int fd, struct hw_stat *hw)
 	char temp_string[BUFSIZ], temp_string2[BUFSIZ];
 	char chip[BUFSIZ], vendor[BUFSIZ], model[BUFSIZ], Mhz[BUFSIZ];
 
+	strcpy(chip, "Unknown");
+	strcpy(vendor, "Unknown");
+	strcpy(model, "Unknown");
+
 	char *p;
 
 	while (read_line(fd, temp_string, BUFSIZ) != 0)
@@ -52,14 +63,25 @@ void GetHardwareInfo(int fd, struct hw_stat *hw)
 				processors++;
 			}
 
-			if (strncmp(temp_string, "Type", strlen("Type")) == 0)
-			{
-				if (strncmp(temp_string2, "sa110", strlen("sa110")) == 0)
-				{
-					strcpy(vendor, "Intel");
-					strcpy(model, "SA110");
+			if (strncmp(temp_string, "CPU implementer", strlen("CPU implementer")) == 0)
+                        {
+			    int i = 0;
+			    int found = 0;
+
+                            while ((implementer[i] != NULL)&&(!found))
+			    {
+				if (strncmp(temp_string2, implementer[i], strlen(implementer[i])) == 0)
+                                {
+				    strcpy(vendor, implementer[++i]);
+		                    found=1;
 				}
-				processors++;
+				i += 2;
+			    }
+			}
+
+			if (strncmp(temp_string, "CPU architecture", strlen("CPU architecture")) == 0)
+                        {
+			    strcpy(model,temp_string2); // v .. instruction set
 			}
 
 			if (strncmp(temp_string, "Type", strlen("Type")) == 0)
@@ -78,7 +100,19 @@ void GetHardwareInfo(int fd, struct hw_stat *hw)
 	sprintf(hw->hw_memory, LONGSPEC, getphysicalmemory());
 	hw->hw_processors = processors;
 
-	sprintf(hw->hw_cpuinfo, "%s %s", vendor, model);
+	// sprintf(hw->hw_cpuinfo, "%s %s", vendor, model);
+	sprintf(hw->hw_cpuinfo, "%s", vendor);
+
+        if (strcmp(model, "Unknown") == 0)
+        {
+	    sprintf(hw->hw_cpuinfo, "%s", vendor);
+	}
+	else
+	{
+	    sprintf(hw->hw_cpuinfo, "%s v%s instruction set", vendor, model);
+	}
+
+
 	if (bogomips == 0.0)
 	    sprintf(hw->hw_bogomips, "?");
 	else
