@@ -12,7 +12,7 @@
 	Copyright (C) 2004
 	Martin Michlmayr <tbm@cyrius.com>
 
-	Copyright (C) 2004-2007,2009,2010,2013 
+	Copyright (C) 2004-2007,2009,2010,2013,2014,2016 
 	Helge Kreutzmann <debian@helgefjell.de>
 
 
@@ -47,6 +47,8 @@
 	1.0.24  KRE     20111104        Add another Xeon
 	1.0.25  KRE     20130527        Add an Athlon X2
 	1.0.26  KRE     20131114        Add another Xeon
+	1.0.27  KRE     20131114        Add another AMD
+	1.0.28  KRE     20160918        Determine fastest CPU
 
         This is the x86 port of linuxinfo
 */
@@ -101,6 +103,7 @@ static char *models[] =
 	"AMD Athlon(tm) 64 X2 Dual Core Processor 5400+", "x86_64",
 	"AMD Phenom(tm) II X6 1055T Processor", "Phenom II",
 	"AMD A6-6310 APU with AMD Radeon R4 Graphics", "A6-6310 with Radeon R4",
+	"AMD FX(tm)-4300 Quad-Core Processor", "x86_64 FX",
         "Am5x86", "5x86",
         "C6", "C6",
 	"C6-2", "C6-2",
@@ -142,6 +145,7 @@ static char *models[] =
 	"Intel(R) Core(TM) Solo CPU     U1400  @ 1.20GHz", "Core Solo",
 	"Intel(R) Core(TM) i7-4600M CPU @ 2.90GHz", "Core i7",
 	"Intel(R) Core(TM)2 CPU          6600  @ 2.40GHz", "Core 2",
+	"Intel(R) Core(TM)2 Duo CPU     E6750  @ 2.66GHz", "Core 2 Duo",
 	"Intel(R) Core(TM)2 Duo CPU     P8600  @ 2.40GHz", "Core 2 Duo",
 	"Intel(R) Core(TM)2 Duo CPU     E7400  @ 2.80GHz", "Core 2 Duo",
 	"Intel(R) Core(TM)2 Duo CPU     E8400  @ 3.00GHz", "Core 2 Duo",
@@ -206,7 +210,10 @@ void GetHardwareInfo(int fd, struct hw_stat *hw)
 				strcpy(family, temp_string2);
 
 			if (strncmp(temp_string, "cpu MHz", strlen("cpu MHz")) == 0)
-				tempMHz = atol(temp_string2);
+			{
+				if (atol(temp_string2) > tempMHz)
+					tempMHz = atol(temp_string2);
+			}
 
 			if (strncmp(temp_string, "bogomips", strlen("bogomips")) == 0)
 				bogomips = bogomips + atof(temp_string2);
